@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use Fl qw[:execute :label :box :font];
+use Fl qw[:execution :label :box :font];
 my $window = Fl::Window->new(100, 100, 300, 180);
 my $box = Fl::Box->new(FL_UP_BOX, 20, 40, 260, 100, 'Hello, World');
 $box->labelfont(FL_BOLD + FL_ITALIC);
